==> record_api-1.1.0.tar.gz: record_api-1.1.0/data/typing/pandas.py <==
from typing import *

# usage.dask: 2
BooleanDtype: object

# usage.xarray: 1
# usage.dask: 20
Categorical: object

# usage.xarray: 2
CategoricalDtype: object

# usage.xarray: 6
# usage.dask: 23
CategoricalIndex: object

# usage.xarray: 12
# usage.dask: 342
DataFrame: object

# usage.xarray: 1
# usage.dask: 1
DateOffset: object

# usage.xarray: 2
# usage.dask: 10
DatetimeIndex: object

# usage.dask: 1
Float64Index: object

# usage.xarray: 1
# usage.dask: 2
Grouper: object

# usage.xarray: 40
# usage.dask: 32
Index: object

# usage.dask: 1
Int16Dtype: object

# usage.dask: 1
Int32Dtype: object

# usage.dask: 2
Int64Dtype: object

# usage.dask: 8
Int64Index: object

# usage.dask: 1
Int8Dtype: object

# usage.xarray: 6
Interval: object

# usage.xarray: 68
# usage.dask: 19
MultiIndex: object

# usage.dask: 4
NA: object

# usage.xarray: 1
# usage.dask: 1
NaT: object

# usage.xarray: 1
Period: object

# usage.xarray: 5
# usage.dask: 6
PeriodIndex: object

# usage.dask: 6
RangeIndex: object

# usage.xarray: 13
# usage.dask: 115
Series: object

# usage.xarray: 1
# usage.dask: 5
Timedelta: object

# usage.dask: 4
TimedeltaIndex: object

# usage.xarray: 2
# usage.dask: 16
Timestamp: object

# usage.dask: 1
UInt16Dtype: object

# usage.dask: 1
UInt32Dtype: object

# usage.dask: 1
UInt64Dtype: object

# usage.dask: 2
UInt64Index: object

# usage.dask: 1
UInt8Dtype: object

# usage.xarray: 6
__version__: object

# usage.dask: 1
_libs: object

# usage.dask: 18
api: object

# usage.dask: 15
array: object

# usage.dask: 33
concat: object

# usage.dask: 12
core: object

# usage.xarray: 1
cut: object

# usage.xarray: 77
# usage.dask: 44
date_range: object

# usage.xarray: 1
factorize: object

# usage.dask: 10
get_dummies: object

# usage.dask: 1
isna: object

# usage.dask: 4
melt: object

# usage.dask: 28
merge: object

# usage.dask: 8
merge_asof: object

# usage.dask: 1
offsets: object

# usage.xarray: 4
# usage.dask: 5
period_range: object

# usage.dask: 4
pivot_table: object

# usage.xarray: 1
plotting: object

# usage.dask: 16
read_csv: object

# usage.dask: 3
read_json: object

# usage.xarray: 5
# usage.dask: 2
testing: object

# usage.xarray: 2
# usage.dask: 3
timedelta_range: object

# usage.xarray: 1
# usage.dask: 7
to_datetime: object

# usage.dask: 3
to_numeric: object

# usage.xarray: 2
# usage.dask: 3
to_timedelta: object

# usage.dask: 6
tseries: object

# usage.dask: 2
util: object

==> record_api-1.2.0.tar.gz: record_api-1.2.0/data/typing/pandas.py <==
from typing import *

# usage.dask: 2
BooleanDtype: object

# usage.dask: 18
# usage.xarray: 1
Categorical: object

# usage.xarray: 2
CategoricalDtype: object

# usage.dask: 23
# usage.xarray: 6
CategoricalIndex: object

# usage.dask: 310
# usage.sklearn: 54
# usage.xarray: 10
DataFrame: object

# usage.dask: 1
# usage.xarray: 2
DateOffset: object

# usage.dask: 10
# usage.xarray: 5
DatetimeIndex: object

# usage.dask: 1
Float64Index: object

# usage.dask: 2
# usage.xarray: 1
Grouper: object

# usage.dask: 32
# usage.xarray: 40
Index: object

# usage.dask: 1
Int16Dtype: object

# usage.dask: 1
Int32Dtype: object

# usage.dask: 2
Int64Dtype: object

# usage.dask: 8
Int64Index: object

# usage.dask: 1
Int8Dtype: object

# usage.xarray: 6
Interval: object

# usage.dask: 19
# usage.xarray: 70
MultiIndex: object

# usage.dask: 4
NA: object

# usage.dask: 1
# usage.xarray: 1
NaT: object

# usage.xarray: 1
Period: object

# usage.dask: 6
# usage.xarray: 5
PeriodIndex: object

# usage.dask: 6
RangeIndex: object

# usage.dask: 102
# usage.sklearn: 11
# usage.xarray: 20
Series: object

# usage.dask: 5
# usage.xarray: 1
Timedelta: object

# usage.dask: 4
# usage.xarray: 9
TimedeltaIndex: object

# usage.dask: 16
# usage.xarray: 2
Timestamp: object

# usage.dask: 1
UInt16Dtype: object

# usage.dask: 1
UInt32Dtype: object

# usage.dask: 1
UInt64Dtype: object

# usage.dask: 2
UInt64Index: object

# usage.dask: 1
UInt8Dtype: object

# usage.dask: 1
# usage.sklearn: 3
# usage.xarray: 6
__version__: object

# usage.dask: 1
_libs: object

# usage.dask: 20
# usage.sklearn: 10
api: object

# usage.dask: 15
array: object

# usage.sklearn: 3
arrays: object

# usage.dask: 31
# usage.sklearn: 2
concat: object

# usage.dask: 12
core: object

# usage.xarray: 1
cut: object

# usage.dask: 51
# usage.xarray: 106
date_range: object

# usage.xarray: 1
factorize: object

# usage.dask: 10
get_dummies: object

# usage.dask: 1
isna: object

# usage.xarray: 1
isnull: object

# usage.dask: 4
melt: object

# usage.dask: 21
merge: object

# usage.dask: 11
merge_asof: object

# usage.dask: 1
offsets: object

# usage.dask: 5
# usage.xarray: 4
period_range: object

# usage.dask: 4
pivot_table: object

# usage.xarray: 1
plotting: object

# usage.dask: 16
# usage.sklearn: 2
read_csv: object

# usage.dask: 3
read_json: object

# usage.dask: 2
# usage.xarray: 5
testing: object

# usage.dask: 3
# usage.xarray: 1
timedelta_range: object

# usage.dask: 8
# usage.xarray: 1
to_datetime: object

# usage.dask: 3
to_numeric: object

# usage.dask: 3
# usage.xarray: 2
to_timedelta: object

# usage.dask: 5
tseries: object

# usage.dask: 2
util: object
